@@ -64,14 +64,12 @@ class User(db.Model):
     """
     __tablename__ = 'user'
 
-    def __init__(self, *args, **kwargs):
-        super(User, self).__init__(*args, **kwargs)
-        self._authenticated = False
-
     email = db.Column(db.String, primary_key=True)
     password = db.Column(db.String)
+    authenticated = db.Column(db.Boolean, default=False)
 
     def is_active(self):
+        """True, as all users are active."""
         return True
 
     def get_id(self):
@@ -79,4 +77,9 @@ class User(db.Model):
         return self.email
 
     def is_authenticated(self):
-        return self._authenticated
+        """Return True if the user is authenticated."""
+        return self.authenticated
+
+    def is_anonymous(self):
+        """False, as anonymous users aren't supported."""
+        return False
